summaryrefslogtreecommitdiffstats
path: root/module/plugins/internal
diff options
context:
space:
mode:
authorGravatar Walter Purcaro <vuolter@users.noreply.github.com> 2015-09-21 00:54:03 +0200
committerGravatar Walter Purcaro <vuolter@users.noreply.github.com> 2015-09-21 00:54:03 +0200
commit97d25752691aa561c29a91166fdd30302bef2db2 (patch)
treee397bf78d74dcce50cec0f6d46eb414b7a6696f7 /module/plugins/internal
parentMerge branch 'pr/n1788_GammaC0de' into stable (diff)
downloadpyload-97d25752691aa561c29a91166fdd30302bef2db2.tar.xz
[Account] parse_info -> grab_info
Diffstat (limited to 'module/plugins/internal')
-rw-r--r--module/plugins/internal/Account.py10
-rw-r--r--module/plugins/internal/XFSAccount.py8
2 files changed, 9 insertions, 9 deletions
diff --git a/module/plugins/internal/XFSAccount.py b/module/plugins/internal/XFSAccount.py
index 3f2158a0b..bef8fc828 100644
--- a/module/plugins/internal/XFSAccount.py
+++ b/module/plugins/internal/XFSAccount.py
@@ -40,7 +40,7 @@ class XFSAccount(Account):
LOGIN_FAIL_PATTERN = r'Incorrect Login or Password|account was banned|Error<'
- def parse_info(self, user, password, data, req):
+ def grab_info(self, user, password, data, req):
validuntil = None
trafficleft = None
leechtraffic = None
@@ -151,7 +151,7 @@ class XFSAccount(Account):
set_cookie(self.req.cj, self.HOSTER_DOMAIN, "lang", "english")
if not self.HOSTER_URL:
- self.login_fail(_("Missing HOSTER_URL"))
+ self.fail_login(_("Missing HOSTER_URL"))
else:
self.HOSTER_URL = self.HOSTER_URL.rstrip('/') + "/"
@@ -180,8 +180,8 @@ class XFSAccount(Account):
except ValueError:
if re.search(self.LOGIN_FAIL_PATTERN, html):
- self.login_fail()
+ self.fail_login()
else:
if not 'success' in json or not json['success']:
- self.login_fail()
+ self.fail_login()
diff --git a/module/plugins/internal/Account.py b/module/plugins/internal/Account.py
index 2713e8da4..07a4a2f81 100644
--- a/module/plugins/internal/Account.py
+++ b/module/plugins/internal/Account.py
@@ -190,7 +190,7 @@ class Account(Plugin):
def get_info(self, user, reload=False):
"""
Retrieve account infos for an user, do **not** overwrite this method!\\
just use it to retrieve infos in hoster plugins. see `parse_info`
:param user: username
:param reload: reloads cached account information
@@ -235,7 +235,7 @@ class Account(Plugin):
try:
self.req = self.get_request(user)
- extra_info = self.parse_info(user, info['login']['password'], info, self.req)
+ extra_info = self.grab_info(user, info['login']['password'], info, self.req)
if extra_info and isinstance(extra_info, dict):
info['data'].update(extra_info)
@@ -253,7 +253,7 @@ class Account(Plugin):
return info
- def parse_info(self, user, password, info, req):
+ def grab_info(self, user, password, info, req):
"""
This should be overwritten in account plugin
and retrieving account information for user
@@ -270,8 +270,8 @@ class Account(Plugin):
return [self.getAccountData(user, *args, **kwargs) for user, info in self.info.items()]
- def login_fail(self, reason=_("Login handshake has failed")):
- return self.fail(reason)
+ def fail_login(self, msg=_("Login handshake has failed")):
+ return self.fail(msg)
def get_request(self, user=None):
@@ -190,7 +190,7 @@ class Account(Plugin):
"""
Retrieve account infos for an user, do **not** overwrite this method!\\
- just use it to retrieve infos in hoster plugins. see `parse_info`
+ just use it to retrieve infos in hoster plugins. see `grab_info`
:param user: username
:param reload: reloads cached account information